<?php
/* picochic Theme Options */
 
function picochic_admin_enqueue_scripts( $hook_suffix ) {
	if ( $hook_suffix != 'appearance_page_theme_options' )
		return;

	wp_enqueue_style( 'picochic-theme-options', get_template_directory_uri().'/includes/theme-options.css', false );
	wp_enqueue_script( 'picochic-theme-options', get_template_directory_uri().'/includes/theme-options.js', array( 'farbtastic' ) );
	wp_enqueue_style( 'farbtastic' );

	wp_enqueue_script('media-upload');
	wp_enqueue_script('thickbox');
	wp_register_script('picochic-image-upload', get_template_directory_uri().'/includes/jquery-upload.js', array(
		'jquery',
		'media-upload',
		'thickbox'
	));
	wp_enqueue_script('picochic-image-upload');
	wp_enqueue_style('thickbox');

	wp_localize_script('picochic-image-upload', 'picochic_localizing_upload_js', array(
		'use_this_image' => __('Use This Image', 'picochic')
    ));
}

add_action( 'admin_enqueue_scripts', 'picochic_admin_enqueue_scripts' );
 
// Default options values
$picochic_options = array(
	'custom_color' => '#364D96',
	'custom_favicon' => '',
	'custom_logo' => '',
	'logo_centered' => '',
	'white_text_color' => '',
	'show_header_search' => '1',
	'custom_header_height' => '200'
);

if ( is_admin() ) : // Load only if we are viewing an admin page

function picochic_register_settings() {
	// Register the settings
	register_setting( 'picochic_theme_options', 'picochic_options', 'picochic_validate_options' );
}

add_action( 'admin_init', 'picochic_register_settings' );


function picochic_theme_options() {
	// Add theme options page to the addmin menu
	add_theme_page( __( 'Options', 'picochic'), __( 'Options', 'picochic'), 'edit_theme_options', 'theme_options', 'picochic_theme_options_page');
}

add_action( 'admin_menu', 'picochic_theme_options' );

// Function to generate options page
function picochic_theme_options_page() {
	global $picochic_options, $picochic_categories, $picochic_layouts;

	if ( ! isset( $_REQUEST['updated'] ) )
		$_REQUEST['updated'] = false; // This checks whether the form has just been submitted. ?>

	<div class="wrap">

	<?php screen_icon(); echo '<h2>'.get_current_theme().' '.__( 'Options', 'picochic' ).'</h2>';
	// This shows the page's name and an icon if one has been provided ?>

	<?php if ( false !== $_REQUEST['updated'] ) : ?>
	<div class="updated fade"><p><strong><?php _e( 'Options saved', 'picochic' ); ?></strong></p></div>
	<?php endif; // If the form has just been submitted, this shows the notification ?>

	<form method="post" action="options.php">

	<?php $settings = get_option( 'picochic_options', $picochic_options ); ?>
	
	<?php settings_fields( 'picochic_theme_options' );
	/* This function outputs some hidden fields required by the form,
	including a nonce, a unique number used to ensure the form has been submitted from the admin page
	and not somewhere else, very important for security */ ?>

	<table class="form-table">

	<tr><td><h3><?php _e('Colors', 'picochic'); ?></h3></td></tr>
	
	<tr valign="top"><th scope="row"><label for="custom_color"><?php _e('Custom Link Color', 'picochic'); ?></label></th>
	<td>
	<input id="custom_color" name="picochic_options[custom_color]" type="text" value="<?php  esc_attr_e($settings['custom_color']); ?>" />
	<a href="#" class="pickcolor hide-if-no-js" id="custom_color-example"></a>
	<input type="button" class="pickcolor button hide-if-no-js" value="<?php esc_attr_e(_e( 'Select a Color', 'picochic' )); ?>">
	<div id="colorPickerDiv" style="z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;"></div>
	<br />
	<small class="description"><?php _e('Default link color', 'picochic'); ?> <a href="javascript:;" id="set_default_color">#364D96</a></small>
	</td>
	</tr>

	<tr valign="top"><th scope="row"><label for="white_text_color"><?php _e('White text color', 'picochic'); ?></label></th>
	<td>		
	<input id="white-text-color" name="picochic_options[white_text_color]" type="checkbox" value="1" <?php checked('1', $settings['white_text_color']); ?> />
	<br />
	<small class="description"><?php _e('Show text color white (for dark backgrounds)', 'picochic'); ?></small>
	</td>
	</tr>

	<tr><td><h3><?php _e('Header', 'picochic'); ?></h3></td></tr>

	<tr valign="top"><th scope="row"><label for="custom_logo"><?php _e('Custom logo', 'picochic'); ?></label></th>
	<td>
	<input id="upload-logo" name="picochic_options[custom_logo]" type="text" value="<?php  esc_attr_e($settings['custom_logo']); ?>" />
	<input type="button" class="button hide-if-no-js" id="upload-logo-button" value="<?php _e('Select or upload a logo', 'picochic'); ?>" />
	<br />
	<small class="description"><a href="javascript:;" id="remove-logo-button"><?php _e('Remove logo and show text instead', 'picochic'); ?></a></small>
	</td>
	</tr>

	<tr valign="top"><th scope="row"><label for="logo_centered"><?php _e('Show logo centered', 'picochic'); ?></label></th>
	<td>		
	<input id="logo-centered" name="picochic_options[logo_centered]" type="checkbox" value="1" <?php checked('1', $settings['logo_centered']); ?> />
	<br />
	<small class="description"><?php _e('Will show logo centered if you set a logo', 'picochic'); ?></small>
	</td>
	</tr>

	<tr valign="top"><th scope="row"><label for="show_header_search"><?php _e('Display header search', 'picochic'); ?></label></th>
	<td>
	<input id="show_header_search" name="picochic_options[show_header_search]" type="checkbox" value="1" <?php checked('1', $settings['show_header_search']); ?> />
	<br />
	<small class="description"><?php _e('If you don\'t like the header search form, you can diasble it here', 'picochic'); ?> </small>
	</td>
	</tr>

	<tr><td><h3><?php _e('Other', 'picochic'); ?></h3></td></tr>

	<tr valign="top"><th scope="row"><label for="custom_favicon"><?php _e('Custom favicon', 'picochic'); ?></label></th>
	<td>
	<input id="upload-favicon" name="picochic_options[custom_favicon]" type="text" value="<?php  esc_attr_e($settings['custom_favicon']); ?>" />
	<input type="button" class="button hide-if-no-js" id="upload-favicon-button" value="<?php _e('Select or upload a favicon', 'picochic'); ?>" />
	<br />
	<small class="description"><a href="javascript:;" id="remove-favicon-button"><?php _e('Remove favicon', 'picochic'); ?></a>. <?php _e('You don\'t have a favicon to upload? Generate your own on', 'picochic'); ?> <a href="http://www.faviconr.com/" target="_blank">faviconr.com</a></small>
	</td>
	</tr>
		
	<tr valign="top"><th scope="row"><label for="custom_header_height"><?php _e('Custom header height', 'picochic'); ?></label></th>
	<td>
	<input id="custom_header_height" name="picochic_options[custom_header_height]" type="text" value="<?php esc_attr_e($settings['custom_header_height']); ?>" />
	<br />
	<small class="description"><?php _e('Default header height:', 'picochic'); ?> <a href="javascript:;" id="custom_header_height_default">200</a> px. <?php _e('After you changed this value you can', 'picochic'); ?> <a href="<?php echo home_url(); ?>/wp-admin/themes.php?page=custom-header" target="_blank"><?php _e('upload a new header image', 'picochic'); ?></a></small>
	</td>
	</tr>
	
	</table>

	<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Save Options', 'picochic'); ?>" /></p>

	</form>

	</div>

	<?php
}

function picochic_validate_options( $input ) {
	global $picochic_options, $picochic_categories, $picochic_layouts;

	$settings = get_option( 'picochic_options', $picochic_options );
	
	// We strip all tags from the text field, to avoid vulnerablilties like XSS
	$input['custom_color'] = wp_filter_nohtml_kses($input['custom_color']);
	$input['custom_header_height'] = wp_filter_nohtml_kses($input['custom_header_height']);
	$input['custom_favicon'] = esc_url_raw($input['custom_favicon']);
	$input['custom_logo'] = esc_url_raw($input['custom_logo']);

	// Our checkbox value is either 0 or 1
	if (!isset($input['logo_centered']))
		$input['logo_centered'] = null;
	$input['logo_centered'] = ($input['logo_centered'] == 1 ? 1 : 0);

	if (!isset($input['white_text_color']))
		$input['white_text_color'] = null;
	$input['white_text_color'] = ($input['white_text_color'] == 1 ? 1 : 0);

	if (!isset($input['show_header_search']))
		$input['show_header_search'] = null;
	$input['show_header_search'] = ($input['show_header_search'] == 1 ? 1 : 0);
	
	return $input;
}

endif;  // EndIf is_admin()


// Custom CSS for Link Colors
function picochic_insert_custom_color(){
?>

<?php
	#$picochic-theme-uri = get_template_directory_uri();
	global $picochic_options;
	$picochic_settings = get_option( 'picochic_options', $picochic_options );
?>

<?php if( $picochic_settings['custom_color'] != '' ) { ?>
	<style type="text/css">
		a, #comments h3, h3#reply-title {color: <?php echo $picochic_settings['custom_color']; ?>;}
        ::selection {
			color: white;
			background: <?php echo $picochic_settings['custom_color']; ?>;
		}
       ::-moz-selection {
			color: white;
			background: <?php echo $picochic_settings['custom_color']; ?>;
		}
		header#headerimage {height: <?php echo $picochic_settings['custom_header_height']; ?>;}
	</style>
<?php } ?>

<?php if($picochic_settings['custom_logo'] != '') { ?>
	<style type="text/css">
		header h1, header .description {display: none;}
	</style>
<?php } ?>

<?php if($picochic_settings['logo_centered'] == '1' && $picochic_settings['custom_logo']) { ?>
	<style type="text/css">
		header {text-align: center;}
		header #logo {padding-left: 0;}
	</style>
<?php } ?>

<?php if($picochic_settings['white_text_color']) { ?>
	<style type="text/css">
		.post .entry, .page .entry, body, aside {color: #fff; }
		nav, footer {
			background: #0C0C0C;
			color: #fff;
		}
		
		a:hover, nav a:hover { 
			color: #E0EF75;
		}

		input, textarea {
			background: #0C0C0C!important;
			text-shadow: none!important;
		}

		input:focus, textarea:focus {
			background: #191919!important;
		}

		input, textarea, nav, footer, .post td, .pages td, .comment td {
			border-color: #6B6B6B;
		}

		article .meta {
			border-top: none!important;
		}
	</style>
<?php } ?>

<?php if($picochic_settings['show_header_search'] != '1') { ?>
	<style type="text/css">
		#headersearch {
			display: none;
		}
	</style>
<?php } ?>

<?php
}

add_action('wp_head', 'picochic_insert_custom_color');
